==> openshift-model-hive-5.12.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneListBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSZoneListBuilder extends io.fabric8.openshift.api.model.hive.v1.DNSZoneListFluentImpl<io.fabric8.openshift.api.model.hive.v1.DNSZoneListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.DNSZoneList,io.fabric8.openshift.api.model.hive.v1.DNSZoneListBuilder>{
  public DNSZoneListBuilder() {
    this(false);
  }
  public DNSZoneListBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSZoneList(), validationEnabled);
  }
  public DNSZoneListBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneListFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneListBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSZoneList(), validationEnabled);
  }
  public DNSZoneListBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneListFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZoneList instance) {
    this(fluent, instance, false);
  }
  public DNSZoneListBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneListFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZoneList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneListBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneList instance) {
    this(instance,false);
  }
  public DNSZoneListBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.DNSZoneListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.DNSZoneList build() {
    DNSZoneList buildable = new DNSZoneList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSZoneListBuilder that = (DNSZoneListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneListBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSZoneListBuilder extends DNSZoneListFluentImpl<DNSZoneListBuilder> implements VisitableBuilder<DNSZoneList,DNSZoneListBuilder>{
  public DNSZoneListBuilder() {
    this(false);
  }
  public DNSZoneListBuilder(Boolean validationEnabled) {
    this(new DNSZoneList(), validationEnabled);
  }
  public DNSZoneListBuilder(DNSZoneListFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneListBuilder(DNSZoneListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSZoneList(), validationEnabled);
  }
  public DNSZoneListBuilder(DNSZoneListFluent<?> fluent,DNSZoneList instance) {
    this(fluent, instance, false);
  }
  public DNSZoneListBuilder(DNSZoneListFluent<?> fluent,DNSZoneList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneListBuilder(DNSZoneList instance) {
    this(instance,false);
  }
  public DNSZoneListBuilder(DNSZoneList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DNSZoneListFluent<?> fluent;
  Boolean validationEnabled;
  public DNSZoneList build() {
    DNSZoneList buildable = new DNSZoneList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
